rdfgenutils
=============
Some simple functions useful when generating RDF from non-RDF sources.

Overview
--------
This is a library of simple functions I use when generating RDF from non-RDF sources.

Installing
----------
Install with easy_install:

    >sudo easy_install rdfgenutils

If you already have it installed then simply upgrade with:

    >sudo easy_install --upgrade rdfgenutils

Author
------
[Ian Davis](http://iandavis.com/), nospam@iandavis.com

Licence
-------
This work is hereby released into the Public Domain. 

To view a copy of the public domain dedication, visit 
[http://creativecommons.org/licenses/publicdomain](http://creativecommons.org/licenses/publicdomain) or send a letter to 
Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
